Changelog
---------

v1.9 (Jun 2024)
    * Using CustomTkinter on top of Tkinter.
    * Use mix of grid and pack layout managers.

v1.0 (May 2024)
    * Works with newer and older matplotlib versions.

v0.99 (Dec 2023)
    * First public version.
